@@ -65,7 +65,7 @@ GtkWidget *border_widget_construct (gchar *panel_id,
 				    BasePState state,
 				    gboolean hidebuttons_enabled,
 				    gboolean hidebutton_pixmaps_enabled,
-				    PanelBackType back_type,
+				    PanelBackgroundType back_type,
 				    char *back_pixmap,
 				    gboolean fit_pixmap_bg,
 				    gboolean stretch_pixmap_bg,
@@ -81,7 +81,7 @@ void border_widget_change_params (BorderWidget *border,
 				  BasePState state,
 				  gboolean hidebuttons_enabled,
 				  gboolean hidebutton_pixmaps_enabled,
-				  PanelBackType back_type,
+				  PanelBackgroundType back_type,
 				  char *pixmap_name,
 				  gboolean fit_pixmap_bg,
 				  gboolean stretch_pixmap_bg,
