@@ -209,12 +209,12 @@ edge_widget_new (gchar *panel_id,
 		 int sz,
 		 gboolean hidebuttons_enabled,
 		 gboolean hidebutton_pixmaps_enabled,
-		 PanelBackType back_type,
+		 PanelBackgroundType back_type,
 		 char *back_pixmap,
 		 gboolean fit_pixmap_bg,
 		 gboolean stretch_pixmap_bg,
 		 gboolean rotate_pixmap_bg,
-		 GdkColor *back_color)
+		 PanelColor *back_color)
 {
 	EdgeWidget  *edgew;
 	BasePWidget *basep;
