@@ -380,12 +380,12 @@ floating_widget_change_params (FloatingWidget *floating,
 			       int sz,
 			       gboolean hidebuttons_enabled,
 			       gboolean hidebutton_pixmap_enabled,
-			       PanelBackType back_type,
+			       PanelBackgroundType back_type,
 			       char *back_pixmap,
 			       gboolean fit_pixmap_bg,
 			       gboolean stretch_pixmap_bg,
 			       gboolean rotate_pixmap_bg,
-			       GdkColor *back_color)
+			       PanelColor *back_color)
 {
 	BasePWidget *basep = BASEP_WIDGET (floating);
 	FloatingPos *pos = FLOATING_POS (basep->pos);
@@ -441,12 +441,12 @@ floating_widget_change_coords (FloatingWidget *floating,
 					       panel->sz,
 					       basep->hidebuttons_enabled,
 					       basep->hidebutton_pixmaps_enabled,
-					       panel->back_type,
-					       panel->back_pixmap,
-					       panel->fit_pixmap_bg,
-					       panel->stretch_pixmap_bg,
-					       panel->rotate_pixmap_bg,
-					       &panel->back_color);
+					       panel->background.type,
+					       panel->background.image,
+					       panel->background.fit_image,
+					       panel->background.stretch_image,
+					       panel->background.rotate_image,
+					       &panel->background.color);
 	}
 }
 
@@ -462,12 +462,12 @@ floating_widget_new (gchar *panel_id,
 		     int sz,
 		     gboolean hidebuttons_enabled,
 		     gboolean hidebutton_pixmap_enabled,
-		     PanelBackType back_type,
+		     PanelBackgroundType back_type,
 		     char *back_pixmap,
 		     gboolean fit_pixmap_bg,
 		     gboolean stretch_pixmap_bg,
 		     gboolean rotate_pixmap_bg,
-		     GdkColor *back_color)
+		     PanelColor *back_color)
 {
 	FloatingWidget *floating;
 	FloatingPos *pos;
