@@ -64,7 +64,7 @@ GtkWidget *sliding_widget_new (gchar *panel_id,
 			       int sz,
 			       gboolean hidebuttons_enabled,
 			       gboolean hidebutton_pixmaps_enabled,
-			       PanelBackType back_type,
+			       PanelBackgroundType back_type,
 			       char *back_pixmap,
 			       gboolean fit_pixmap_bg,
 			       gboolean stretch_pixmap_bg,
@@ -82,7 +82,7 @@ void sliding_widget_change_params (SlidingWidget *slidingw,
 				   BasePState state,
 				   gboolean hidebuttons_enabled,
 				   gboolean hidebutton_pixmaps_enabled,
-				   PanelBackType back_type,
+				   PanelBackgroundType back_type,
 				   char *pixmap_name,
 				   gboolean fit_pixmap_bg,
 				   gboolean stretch_pixmap_bg,
