@@ -58,24 +58,24 @@ struct _PanelAppletPrivate {
 	BonoboPropertyBag          *prop_sack;
 	BonoboItemHandler          *item_handler;
 
-	gchar                      *iid;
+	char                       *iid;
 	GClosure                   *closure;
 	gboolean                    bound;
-	gchar                      *prefs_key;
+	char                       *prefs_key;
 
 	PanelAppletFlags            flags;
 	PanelAppletOrient           orient;
 	guint                       size;
-	gchar                      *background;
+	char                       *background;
 
 	GdkPixmap                  *bg_pixmap;
 
         int                        *size_hints;
         int                         size_hints_len;
 
-	gboolean		    moving_focus_out;
-	gint		   	    focusable_child;
-	guint			    hierarchy_changed_id;
+	gboolean                    moving_focus_out;
+	int                         focusable_child;
+	guint                       hierarchy_changed_id;
 };
 
 static GObjectClass *parent_class;
@@ -398,6 +398,7 @@ panel_applet_finalize (GObject *object)
 		bonobo_object_unref (
 			BONOBO_OBJECT (applet->priv->prop_sack));
 
+	g_free (applet->priv->size_hints);
 	g_free (applet->priv->prefs_key);
 	g_free (applet->priv->background);
 	g_free (applet->priv->iid);
@@ -794,7 +795,7 @@ panel_applet_get_pixmap (PanelApplet     *applet,
 			 int              x,
 			 int              y)
 {
-	GdkPixmap *pixmap;
+	GdkWindow *window;
 	GdkPixmap *retval;
 	GdkGC     *gc;
 	int        width;
@@ -802,13 +803,16 @@ panel_applet_get_pixmap (PanelApplet     *applet,
 
 	g_return_val_if_fail (PANEL_IS_APPLET (applet), NULL);
 
-	pixmap = gdk_pixmap_lookup (xid);
-	if (pixmap)
-		g_object_ref (G_OBJECT (pixmap));
-	else
-		pixmap = gdk_pixmap_foreign_new (xid);
+	if (!GTK_WIDGET_REALIZED (applet))
+		return NULL;
 
-	g_return_val_if_fail (pixmap != NULL, NULL);
+	window = gdk_window_lookup (xid);
+	if (window)
+		g_object_ref (window);
+	else
+		window = gdk_window_foreign_new (xid);
+
+	g_return_val_if_fail (window != NULL, NULL);
 
 	gdk_drawable_get_size (GDK_DRAWABLE (GTK_WIDGET (applet)->window),
 			       &width, &height);
@@ -821,13 +825,13 @@ panel_applet_get_pixmap (PanelApplet     *applet,
 
 	gdk_draw_drawable (GDK_DRAWABLE (retval),
 			   gc, 
-			   GDK_DRAWABLE (pixmap),
+			   GDK_DRAWABLE (window),
 			   x, y,
 			   0, 0,
 			   width, height);
 
 	g_object_unref (gc);
-	g_object_unref (pixmap);
+	g_object_unref (window);
 
 	return retval;
 }
@@ -842,7 +846,7 @@ panel_applet_handle_background_string (PanelApplet  *applet,
 
 	retval = PANEL_NO_BACKGROUND;
 
-	if (!applet->priv->background)
+	if (!GTK_WIDGET_REALIZED (applet) || !applet->priv->background)
 		return retval;
 
 	elements = g_strsplit (applet->priv->background, ":", -1);
@@ -967,6 +971,39 @@ panel_applet_get_prop (BonoboPropertyBag *sack,
 	}
 }
 
+static void
+panel_applet_handle_background (PanelApplet *applet)
+{
+	PanelAppletBackgroundType  type;
+	GdkColor                   color;
+	GdkPixmap                 *pixmap = NULL;
+
+	type = panel_applet_handle_background_string (applet, &color, &pixmap);
+
+	switch (type) {
+	case PANEL_NO_BACKGROUND:
+		g_signal_emit (G_OBJECT (applet),
+			       panel_applet_signals [CHANGE_BACKGROUND],
+			       0, PANEL_NO_BACKGROUND, NULL, NULL);
+		break;
+	case PANEL_COLOR_BACKGROUND:
+		g_signal_emit (G_OBJECT (applet),
+			       panel_applet_signals [CHANGE_BACKGROUND],
+			       0, PANEL_COLOR_BACKGROUND, &color, NULL);
+		break;
+	case PANEL_PIXMAP_BACKGROUND:
+		g_signal_emit (G_OBJECT (applet),
+			       panel_applet_signals [CHANGE_BACKGROUND],
+			       0, PANEL_PIXMAP_BACKGROUND, NULL, pixmap);
+
+		g_object_unref (pixmap);
+		break;
+	default:
+		g_assert_not_reached ();
+		break;
+	}
+}
+
 static void
 panel_applet_set_prop (BonoboPropertyBag *sack,
 		       const BonoboArg   *arg,
@@ -1005,42 +1042,13 @@ panel_applet_set_prop (BonoboPropertyBag *sack,
 		}
 		}
 		break;
-	case PROPERTY_BACKGROUND_IDX: {
-		PanelAppletBackgroundType  type;
-		GdkColor                   color;
-		GdkPixmap                 *pixmap = NULL;
-
-
+	case PROPERTY_BACKGROUND_IDX:
 		if (applet->priv->background)
 			g_free (applet->priv->background);
 
 		applet->priv->background = g_strdup (BONOBO_ARG_GET_STRING (arg));
 
-		type = panel_applet_handle_background_string (applet, &color, &pixmap);
-
-		switch (type) {
-		case PANEL_NO_BACKGROUND:
-			g_signal_emit (G_OBJECT (applet),
-				       panel_applet_signals [CHANGE_BACKGROUND],
-				       0, PANEL_NO_BACKGROUND, NULL, NULL);
-			break;
-		case PANEL_COLOR_BACKGROUND:
-			g_signal_emit (G_OBJECT (applet),
-				       panel_applet_signals [CHANGE_BACKGROUND],
-				       0, PANEL_COLOR_BACKGROUND, &color, NULL);
-			break;
-		case PANEL_PIXMAP_BACKGROUND:
-			g_signal_emit (G_OBJECT (applet),
-				       panel_applet_signals [CHANGE_BACKGROUND],
-				       0, PANEL_PIXMAP_BACKGROUND, NULL, pixmap);
-
-			g_object_unref (pixmap);
-			break;
-		default:
-			g_assert_not_reached ();
-			break;
-		}
-		}
+		panel_applet_handle_background (applet);
 		break;
 	default:
 		g_assert_not_reached ();
@@ -1100,6 +1108,15 @@ panel_applet_property_bag (PanelApplet *applet)
 	return sack;
 }
 
+static void
+panel_applet_realize (GtkWidget *widget)
+{
+	GTK_WIDGET_CLASS (parent_class)->realize (widget);
+
+	if (PANEL_APPLET (widget)->priv->background)
+		panel_applet_handle_background (PANEL_APPLET (widget));
+}
+
 static void
 panel_applet_control_bound (BonoboControl *control,
 			    PanelApplet   *applet)
@@ -1266,6 +1283,7 @@ panel_applet_class_init (PanelAppletClass *klass,
 	widget_class->size_allocate = panel_applet_size_allocate;
 	widget_class->expose_event = panel_applet_expose;
 	widget_class->focus = panel_applet_focus;
+	widget_class->realize = panel_applet_realize;
 
 	gobject_class->finalize = panel_applet_finalize;
 
@@ -1452,110 +1470,6 @@ panel_applet_callback_data_free (PanelAppletCallBackData *data)
 	g_free (data);
 }
 
-/*
- *   Time we're prepared to wait without a ControlFrame
- * before terminating the Control. This can happen if the
- * panel activates us but crashes before the set_frame.
- *
- * NB. if we don't get a frame in 30 seconds, something
- * is badly wrong, or Gnome performance needs improving
- * markedly !
- */
-#define PANEL_APPLET_NEVER_GOT_FRAME_TIMEOUT 30 * 1000 /* ms */
-
-/* Track the living controls */
-static GSList *active_controls = NULL;
-
-static gboolean
-panel_applet_idle_quit (gpointer data)
-{
-	if (!active_controls)
-		bonobo_main_quit ();
-
-	return FALSE;
-}
-
-static void
-panel_applet_cnx_broken_callback (BonoboControl *control)
-{
-	active_controls = g_slist_remove (active_controls, control);
-	if (!active_controls)
-		g_idle_add (panel_applet_idle_quit, NULL);
-}
-
-static gboolean
-panel_applet_never_got_frame_timeout (gpointer user_data)
-{
-	g_warning ("Never got frame, panel died - abnormal exit condition");
-
-	panel_applet_cnx_broken_callback (user_data);
-	
-	return FALSE;
-}
-
-static void
-panel_applet_set_frame_callback (BonoboControl *control,
-				 gpointer       user_data)
-{
-	Bonobo_ControlFrame remote_frame;
-
-	remote_frame = bonobo_control_get_control_frame (control, NULL);
-
-	if (remote_frame != CORBA_OBJECT_NIL) {
-		ORBitConnectionStatus status;
-
-		g_source_remove (GPOINTER_TO_UINT (user_data));
-
-		status = ORBit_small_get_connection_status (remote_frame);
-
-		/* Only track out of proc controls */
-		if (status != ORBIT_CONNECTION_IN_PROC) {
-			active_controls = g_slist_prepend (active_controls,
-							   control);
-
-			g_signal_connect_closure (
-				ORBit_small_get_connection (remote_frame),
-				"broken",
-				g_cclosure_new_object_swap (
-					G_CALLBACK (panel_applet_cnx_broken_callback),
-					G_OBJECT (control)),
-				FALSE);
-			g_signal_connect (
-				control, "destroy",
-				G_CALLBACK (panel_applet_cnx_broken_callback),
-				NULL);
-		}
-	}
-}
-
-/**
- * panel_applet_instrument_for_failure:
- * @control: the control.
- * 
- *   Don't read this method - just believe in it; it'll
- * move inside libbonoboui in due course.
- **/
-static void
-panel_applet_instrument_for_failure (BonoboControl *control)
-{
-	guint no_frame_timeout_id;
-
-	no_frame_timeout_id = g_timeout_add (
-		PANEL_APPLET_NEVER_GOT_FRAME_TIMEOUT,
-		panel_applet_never_got_frame_timeout,
-		control);
-	g_signal_connect_closure (
-		control, "destroy",
-		g_cclosure_new_swap (
-			G_CALLBACK (g_source_remove_by_user_data),
-			control, NULL),
-		0);
-	g_signal_connect (
-		control, "set_frame",
-		G_CALLBACK (panel_applet_set_frame_callback),
-		GUINT_TO_POINTER (no_frame_timeout_id));
-}
-
 static BonoboObject *
 panel_applet_factory_callback (BonoboGenericFactory    *factory,
 			       const char              *iid,
@@ -1570,11 +1484,18 @@ panel_applet_factory_callback (BonoboGenericFactory    *factory,
 	applet->priv->iid     = g_strdup (iid);
 	applet->priv->closure = g_closure_ref (data->closure);
 
-	panel_applet_instrument_for_failure (applet->priv->control);
-	
+	bonobo_control_life_instrument (applet->priv->control);
+
 	return BONOBO_OBJECT (applet->priv->control);
 }
 
+static void
+panel_applet_all_controls_dead (void)
+{
+	if (!bonobo_control_life_get_count())
+		bonobo_main_quit ();
+}
+
 /**
  * panel_applet_factory_main_closure:
  * @iid: The bonobo-activation iid of the factory.
@@ -1602,6 +1523,8 @@ panel_applet_factory_main_closure (const gchar *iid,
 	bindtextdomain (GETTEXT_PACKAGE, GNOMELOCALEDIR);
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 
+	bonobo_control_life_set_callback (panel_applet_all_controls_dead);
+
 	closure = bonobo_closure_store (closure, panel_applet_marshal_BOOLEAN__STRING);
 
 	data = panel_applet_callback_data_new (applet_type, closure);
